/***************************************************************************
 *
 * Copyright (C) 2005 Elad Lahav (elad_lahav@users.sourceforge.net)
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 ***************************************************************************/

#ifndef GRAPHEDGE_H
#define GRAPHEDGE_H

#include <qcanvas.h>
#include "graphviz.h"

/**
 * Draws a directed edge on a canvas.
 * The edge is composed of a spline, which is its body, and a polygon, which
 * is its head.
 * @author Elad Lahav
 */
class GraphEdge : public QCanvasPolygonalItem
{
public:
    GraphEdge(QCanvas*, Agedge_t*);
    ~GraphEdge();

	/**
	 * @return	The graph edge drawn by this item.
	 */
	Agedge_t* getEdge() { return m_pEdge; }
	
	void setPolyPoints(const QPointArray&);
	void setCurvePoints(const QPointArray&);
	
	/**
	 * Returns the area surrounding the edge.
	 * @return	A point array defining the area occupied by this item
	 */
	virtual QPointArray areaPoints() const { return m_arrArea; }
	
	/**
	 * @return	 The bounding rectangle of the edge's head
	 */
	const QRect& boundingRect() { return m_rcBound; }
	
protected:
	virtual void drawShape(QPainter&);
	
private:
	/** The graph edge drawn by this item. */
	Agedge_t* m_pEdge;
	
	/** The points of the polygon part of the edge. */
	QPointArray m_arrPoly;
	
	/** Control points for the spline part of the edge. */
	QPointArray m_arrCurve;
	
	/** Points surrounding the entire edge. */
	QPointArray m_arrArea;
	
	/** The bounding rectangle of the edge's head. */
	QRect m_rcBound;
	
	void calcArea();
};

#endif
