/***************************************************************************
 *
 * Copyright (C) 2005 Elad Lahav (elad_lahav@users.sourceforge.net)
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 ***************************************************************************/

#include <qpainter.h>
#include <qfontmetrics.h>
#include "graphnode.h"

int GraphNode::RTTI = 1001;

/**
 * Class constructor.
 * @param	pCanvas	The owner canvas
 * @param	pNode	The graph node
 */
GraphNode::GraphNode(QCanvas* pCanvas, Agnode_t* pNode) :
	QCanvasPolygon(pCanvas),
	m_pNode(pNode)
{
}

/**
 * Class destructor.
 */
GraphNode::~GraphNode()
{
}

/**
 * Draws the node.
 * @param	painter	Used for drawing the item on the canvas view
 */
void GraphNode::draw(QPainter& painter)
{
	QFontMetrics fm(m_font);
	QPoint pt;
	
	// Draw the polygon
	painter.setPen(QPen(Qt::black));
	painter.setBrush(brush());
	painter.drawConvexPolygon(points());
	
	// Draw the text
	painter.setPen(pen());
	painter.setFont(m_font);
	pt.setX(m_ptTextPos.x() - fm.width(m_sText) / 2);
	pt.setY(m_ptTextPos.y());
	painter.drawText(pt, m_sText);
}
