/***************************************************************************
 *
 * Copyright (C) 2005 Elad Lahav (elad_lahav@users.sourceforge.net)
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 ***************************************************************************/

#ifndef GRAPHNODE_H
#define GRAPHNODE_H

#include <qcanvas.h>
#include "graphviz.h"

/**
 * A canvas item that draws the name of a function insider a filled rectangle.
 * This item represents a function in the call graph.
 * @author Elad Lahav
 */
class GraphNode : public QCanvasPolygon
{
public:
	GraphNode(QCanvas*, Agnode_t*);
	~GraphNode();
	
	/**
	 * @return	The graph node drawn by this item
	 */
	Agnode_t* getNode() { return m_pNode; }

	/**
	 * @param	font	The font to use for drawing the text
	 */
	void setFont(const QFont& font) { m_font = font; }
	
	/**
	 * @param	sText	The text to draw
	 */
	void setText(const QString& sText) { m_sText = sText; }
	
	/**
	 * @param	ptTextPos	The position of the text
	 */
	void setTextPos(const QPoint& ptTextPos) { m_ptTextPos = ptTextPos;	}
	
	/**
	 * @return	The name of the function
	 */
	const QString& getText() const { return m_sText; }
	
	/** Identifies this class among other QCanvasItem classes. */
	static int RTTI;

	/** @return	The class identifier. */
	virtual int rtti() const { return RTTI; }
	
protected:
	virtual void draw(QPainter&);
	
private:
	/** The graph node drawn by this item. */
	Agnode_t* m_pNode;
	
	/** The name of the function to draw. */
	QString m_sText;

	/** The location of the text to draw. */
	QPoint m_ptTextPos;

	/** The font to use for drawing the text. */
	QFont m_font;
};

#endif
